@@ -1,6 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright (C) 2002-2006 Juan David Ibáñez Palomar <jdavid@itaapy.com>
-# Copyright (C) 2005 Luis Arturo Belmar-Letelier <luis@itaapy.com>
+# Copyright (C) 2006, 2008 Juan David Ibáñez Palomar <jdavid@itaapy.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,8 +19,8 @@ from utils import get_version, get_abspath
 from gettext import register_domain
 
 
-__version__ = get_version(globals())
+__version__ = get_version()
 
 # Register the itools domain
-path = get_abspath(globals(), 'locale')
+path = get_abspath('locale')
 register_domain('itools', path)
