@@ -15,10 +15,11 @@ Released under the terms of the GPL, version 3.
 $Id: css.py 45 2007-11-29 17:40:52Z andrew $
 """
 
-from UserDict import UserDict
-
+# Import from the Standard Library
 import sys
 from os.path import isdir, join, exists, abspath
+
+# Import from itools
 from itools.utils import freeze
 
 
@@ -219,7 +220,7 @@ class CssRule(object):
     }
 
 
-    def __init__(self, selector, properties={}):
+    def __init__(self, selector, properties=freeze({})):
 
         """
         Constructor.
@@ -260,7 +261,7 @@ class CssRule(object):
 
 
 
-class CssProperties(UserDict):
+class CssProperties(dict):
 
     """
     Like a dictionary, except it has things like get_int and get_list methods.
