@@ -19,12 +19,17 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+# Import from itools
+from itools.utils import freeze
+from utils import font_value, format_size, get_color_as_hexa
+from utils import get_color, get_int_value
+
+# Import from reportlab
 from reportlab.lib.enums import TA_LEFT, TA_CENTER, TA_RIGHT, TA_JUSTIFY
 from reportlab.lib.styles import ParagraphStyle
 from reportlab.lib.units import cm
 from reportlab.platypus.frames import ShowBoundaryValue
-from utils import (font_value, format_size, get_color_as_hexa,
-                   get_color, get_int_value)
+
 
 P_ALIGNMENTS = {'left': TA_LEFT, 'right': TA_RIGHT, 'center': TA_CENTER,
               'justify': TA_JUSTIFY}
@@ -56,6 +61,7 @@ BODY_MARGINS = {'margin-top': 'topMargin',
                 'margin-right': 'rightMargin'}
 
 
+
 def get_align(attributes):
     attrs = {}
     hAlign = attributes.get((None, 'align'), None)
@@ -352,7 +358,7 @@ def body_margin_style(key, value):
     return style_attr
 
 
-def build_frame_style(context, style_css, inline_attributes={}):
+def build_frame_style(context, style_css, inline_attributes=freeze({})):
     frame_attr = {}
     border = {}
     # The default style is Normal
@@ -552,9 +558,9 @@ def get_table_style(style_css, attributes, start, stop):
                     continue
                 key, value = data.split(':') # FIXME to do more robust
                 style_css2[key] = value
-        table_style.extend(_get_table_style(style_css, start, stop))
-        border_css_buffer.update(_get_table_style_border_only(style_css,
-                                                              start, stop))
+            table_style.extend(_get_table_style(style_css, start, stop))
+            border_css_buffer.update(_get_table_style_border_only(style_css2,
+                                                                  start, stop))
 
     keys = border_css_buffer.keys()
     keys.sort()
