@@ -1,7 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 # Copyright (C) 2007 David Versmisse <david.versmisse@itaapy.com>
-# Copyright (C) 2007 Juan David Ibáñez Palomar <jdavid@itaapy.com>
+# Copyright (C) 2007-2008 Juan David Ibáñez Palomar <jdavid@itaapy.com>
+# Copyright (C) 2008 Henry Obein <henry@itaapy.com>
+# Copyright (C) 2008 Sylvain Taverne <sylvain@itaapy.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -45,40 +47,42 @@ except ImportError:
 
 # Import from itools
 import itools
+from itools.handlers import merge_dics
 from itools.utils import get_abspath
 from itools import git, vfs
 from itools.datatypes import Unicode, Integer, DateTime
 
 
 # Define list of problems
-code_length = {'title': u'Code length',
-               'keys':
-                  {'lines': u'Number of lines',
-                   'tokens': u'Number of tokens'},
-                'pourcent': False}
+code_length = {
+    'title': u'Code length',
+    'keys': {'lines': u'Number of lines', 'tokens': u'Number of tokens'},
+    'pourcent': False}
 
-aesthetics_problems = {'title': u'Aesthetics (and readibility)',
-                       'keys':
-                           {'tabs':  u'with tabulators',
-                           'bad_indentation': u'bad indented',
-                           'bad_length': u'longer than 79 characters',
-                           'bad_end': u'with trailing whitespaces'},
-                        'pourcent': True}
+aesthetics_problems = {
+     'title': u'Aesthetics (and readibility)',
+     'keys': {'tabs':  u'with tabulators',
+              'bad_indentation': u'bad indented',
+              'bad_length': u'longer than 79 characters',
+              'bad_end': u'with trailing whitespaces'},
+     'pourcent': True}
 
-exception_problems = {'title': u'Exception handling',
-                      'keys':
-                          {'string_exception': u'string exceptions are used',
-                           'except_all': u'all exceptions are catched'},
-                        'pourcent': False}
+exception_problems = {
+    'title': u'Exception handling',
+    'keys': {'string_exception': u'string exceptions are used',
+             'except_all': u'all exceptions are catched'},
+    'pourcent': False}
 
-import_problems = {'title': u'Import problems',
-                   'keys': {'bad_import': 'misplaced imports'},
-                   'pourcent': False}
+import_problems = {
+    'title': u'Import problems',
+    'keys': {'bad_import': 'misplaced imports'},
+    'pourcent': False}
+
+problems = merge_dics(
+    aesthetics_problems['keys'],
+    exception_problems['keys'],
+    import_problems['keys'])
 
-problems = {}
-problems.update(aesthetics_problems['keys'])
-problems.update(exception_problems['keys'])
-problems.update(import_problems['keys'])
 
 
 def analyse_file_pass1(filename):
@@ -339,7 +343,7 @@ def create_graph():
     project_name = getcwd().split('/')[-1]
     # We copy project to tmp (for security)
     current_directory = getcwd()
-    tmp_directory = '%s/isetup_quality.git/' % mkdtemp()
+    tmp_directory = '%s/isetup_quality.git' % mkdtemp()
     popen('git clone %s %s' % (current_directory, tmp_directory))
     chdir(tmp_directory)
     # First step: we create a list of statistics
