@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright (C) 2005 Nicolas Oyez <nicoyez@gmail.com>
-# Copyright (C) 2005-2007 Juan David Ibáñez Palomar <jdavid@itaapy.com>
+# Copyright (C) 2005-2008 Juan David Ibáñez Palomar <jdavid@itaapy.com>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@ import unittest
 from unittest import TestCase
 
 # Import from itools
-from itools.tmx import TMX
+from itools.tmx import TMXFile
 
 
 
@@ -29,7 +29,7 @@ class TMXTestCase(TestCase):
     def test_input(self):
         """Test input.
         """
-        tmx = TMX('tests/localizermsgs.tmx')
+        tmx = TMXFile('tests/localizermsgs.tmx')
         tmx.to_str()
 
 
